@@ -1,4 +1,5 @@
 import os
+import six
 import shutil
 from django.conf import settings
 from optparse import make_option
@@ -14,7 +15,8 @@ custom_options = (
         action="store",
         dest="build_dir",
         default='',
-        help="Specify the path of the build directory. Will use settings.BUILD_DIR by default."
+        help="Specify the path of the build directory. \
+Will use settings.BUILD_DIR by default."
     ),
     make_option(
         "--skip-static",
@@ -36,15 +38,17 @@ custom_options = (
 class Command(BaseCommand):
     help = 'Bake out a site as flat files in the build directory'
     option_list = BaseCommand.option_list + custom_options
-    build_unconfig_msg = "Build directory unconfigured. Set BUILD_DIR in settings.py or provide it with --build-dir"
-    views_unconfig_msg = "Bakery views unconfigured. Set BAKERY_VIEWS in settings.py or provide a list as arguments."
-    
+    build_unconfig_msg = "Build directory unconfigured. Set BUILD_DIR in \
+settings.py or provide it with --build-dir"
+    views_unconfig_msg = "Bakery views unconfigured. Set BAKERY_VIEWS in \
+settings.py or provide a list as arguments."
+
     def handle(self, *args, **options):
         """
         Making it happen.
         """
         self.verbosity = int(options.get('verbosity'))
-        
+
         # Figure out what build directory to use
         if options.get("build_dir"):
             self.build_dir = options.get("build_dir")
@@ -53,20 +57,20 @@ class Command(BaseCommand):
             if not hasattr(settings, 'BUILD_DIR'):
                 raise CommandError(self.build_unconfig_msg)
             self.build_dir = settings.BUILD_DIR
-        
+
         # Destroy the build directory, if it exists
         if self.verbosity > 1:
-            print "Creating build directory"
+            six.print_("Creating build directory")
         if os.path.exists(self.build_dir):
             shutil.rmtree(self.build_dir)
-        
+
         # Then recreate it from scratch
         os.makedirs(self.build_dir)
-        
+
         # Build up static files
         if not options.get("skip_static"):
             if self.verbosity > 1:
-                print "Creating static directory"
+                six.print_("Creating static directory")
             management.call_command(
                 "collectstatic",
                 interactive=False,
@@ -77,17 +81,17 @@ class Command(BaseCommand):
                     settings.STATIC_ROOT,
                     os.path.join(self.build_dir, settings.STATIC_URL[1:])
                 )
-        
+
         # Build the media directory
         if not options.get("skip_media"):
             if self.verbosity > 1:
-                print "Building media directory"
+                six.print_("Building media directory")
             if os.path.exists(settings.MEDIA_ROOT) and settings.MEDIA_URL:
                 shutil.copytree(
                     settings.MEDIA_ROOT,
                     os.path.join(self.build_dir, settings.MEDIA_URL[1:])
                 )
-        
+
         # Figure out what views we'll be using
         if args:
             view_list = args
@@ -95,11 +99,11 @@ class Command(BaseCommand):
             if not hasattr(settings, 'BAKERY_VIEWS'):
                 raise CommandError(self.views_unconfig_msg)
             view_list = settings.BAKERY_VIEWS
-        
+
         # Then loop through and run them all
         for view_str in view_list:
             if self.verbosity > 1:
-                print "Building %s" % view_str
+                six.print_("Building %s" % view_str)
             try:
                 view = get_callable(view_str)
                 view().build_method()
